Uses of Class
software.constructs.Construct
-
-
Uses of Construct in software.constructs
Methods in software.constructs that return Construct Modifier and Type Method Description ConstructConstruct.Builder. build()ConstructValidationError. getSource()The construct which emitted the error.ConstructValidationError.Jsii$Proxy. getSource()Methods in software.constructs with parameters of type Construct Modifier and Type Method Description static Construct.BuilderConstruct.Builder. create(Construct scope, String id)NodeINodeFactory. createNode(Construct host, IConstruct scope, String id)Returns a new `Node` associated with `host`.default NodeINodeFactory.Jsii$Default. createNode(Construct host, IConstruct scope, String id)Returns a new `Node` associated with `host`.NodeINodeFactory.Jsii$Proxy. createNode(Construct host, IConstruct scope, String id)Returns a new `Node` associated with `host`.ValidationError.BuilderValidationError.Builder. source(Construct source)Sets the value ofValidationError.getSource()Constructors in software.constructs with parameters of type Construct Constructor Description Construct(Construct scope, String id)Creates a new construct node.Construct(Construct scope, String id, ConstructOptions options)Creates a new construct node.Node(Construct host, IConstruct scope, String id)
-